@@ -88,8 +88,8 @@ BOOL CPluginsDlg::OnInitDialog()
 {
 	CDialog::OnInitDialog();
 	
-int iColOrder [eColumnCount] = {0, 1, 2, 3, 4, 5},
-    iColWidth [eColumnCount] = {50, 130, 55, 55, 80, 30};
+int iColOrder [eColumnCount] = {0, 1, 2, 3, 4, 5, 6},
+    iColWidth [eColumnCount] = {50, 130, 55, 55, 80, 30, 20};
 
 // set list control to display whole row when selected and to allow column drag/drop
 
@@ -100,12 +100,17 @@ int iColOrder [eColumnCount] = {0, 1, 2, 3, 4, 5},
   if (iColWidth [eColumnEnabled] < 20)
      iColWidth [eColumnEnabled] = 20;
 
+  // for upgrading
+  if (iColWidth [eColumnVersion] < 20)
+     iColWidth [eColumnVersion] = 20;
+
  m_ctlPluginList.InsertColumn(eColumnName, TranslateHeading ("Name"), LVCFMT_LEFT, iColWidth [eColumnName]);
  m_ctlPluginList.InsertColumn(eColumnPurpose, TranslateHeading ("Purpose"), LVCFMT_LEFT, iColWidth [eColumnPurpose]);
  m_ctlPluginList.InsertColumn(eColumnAuthor, TranslateHeading ("Author"), LVCFMT_LEFT, iColWidth [eColumnAuthor]);
  m_ctlPluginList.InsertColumn(eColumnLanguage, TranslateHeading ("Language"), LVCFMT_LEFT, iColWidth [eColumnLanguage]);
  m_ctlPluginList.InsertColumn(eColumnFile, TranslateHeading ("File"), LVCFMT_LEFT, iColWidth [eColumnFile]);
  m_ctlPluginList.InsertColumn(eColumnEnabled, TranslateHeading ("Enabled"), LVCFMT_LEFT, iColWidth [eColumnEnabled]);
+ m_ctlPluginList.InsertColumn(eColumnVersion, TranslateHeading ("Ver"), LVCFMT_RIGHT, iColWidth [eColumnVersion]);
                                                        
 // recover column sequence
 
@@ -156,6 +161,11 @@ int iResult;
       if (iResult == 0)
         iResult = item1->m_strName.CompareNoCase (item2->m_strName); 
       break;
+    case eColumnVersion:
+      iResult = item1->m_dVersion < item2->m_dVersion; 
+      if (iResult == 0)
+        iResult = item1->m_strName.CompareNoCase (item2->m_strName); 
+      break;
 
     default: return 0;
     } // end of switch
@@ -187,6 +197,7 @@ int nItem = 0;
 	  m_ctlPluginList.SetItemText (nItem, eColumnLanguage, p->m_strLanguage);
 	  m_ctlPluginList.SetItemText (nItem, eColumnFile, p->m_strSource);
     m_ctlPluginList.SetItemText (nItem, eColumnEnabled, p->m_bEnabled ? "Yes" : "No");
+    m_ctlPluginList.SetItemText (nItem, eColumnVersion, CFormat ("%5.2f", p->m_dVersion));
     m_ctlPluginList.SetItemData (nItem, (DWORD) p);
 
     }
