@@ -637,7 +637,7 @@ assemble the full text of the original line.
   	  	{
   			CMUSHView* pmyView = (CMUSHView*)pView;
 
-  			pmyView->InvalidateLines (iLineCount);
+  			pmyView->Invalidate ();
 
   		  }	  // end of being an output view
   	  }   // end of doing each view
