@@ -8,8 +8,13 @@
 #include "mainfrm.h"
 #include "color.h"
 
+#include "errors.h"
+
 #include "pcre_internal.h"
 
+#define PNG_NO_CONSOLE_IO
+#include "png.h"
+
 #ifdef _DEBUG
 //#define new DEBUG_NEW
 #undef THIS_FILE
@@ -2970,3 +2975,150 @@ void SendToFront (const char * name)
   EnumWindows (&EnumWindowsProc, (int) name);
   } /* end of send_to_front */
 
+
+static void user_error_fn(png_structp png_ptr,
+        png_const_charp error_msg)
+  {
+//  AfxMessageBox (error_msg);
+  }
+
+static void user_warning_fn(png_structp png_ptr,
+    png_const_charp warning_msg)
+  {
+//  AfxMessageBox (warning_msg);
+
+  }
+
+static int BytesPerLine (int nWidth, int nBitsPerPixel)
+  {
+  return ( (nWidth * nBitsPerPixel + 31) & (~31) ) / 8;
+  }
+
+long LoadPng (LPCTSTR FileName, HBITMAP & hbmp)  // load a PNG file into a bitmap
+  {
+  // open file
+  FILE *fp = fopen(FileName, "rb");
+  if (!fp)
+      return (eFileNotFound);
+
+unsigned char header [8];
+                  
+  // read signature
+  if (fread(header, 1, sizeof header, fp) != sizeof header)
+    {
+    fclose (fp);
+    return (eUnableToLoadImage);    // file too small
+    }
+
+  // check signature
+  if (png_sig_cmp(header, 0, sizeof header))
+    {
+    fclose (fp);
+    return (eUnableToLoadImage);   // bad signature
+    }
+
+  // create PNG structure
+  png_structp png_ptr = png_create_read_struct
+       (PNG_LIBPNG_VER_STRING, NULL,
+        user_error_fn, user_warning_fn);
+
+  if (!png_ptr)
+    {
+    fclose (fp);
+    return eUnableToLoadImage;
+    }
+
+  // create info structure
+  png_infop info_ptr = png_create_info_struct(png_ptr);
+  if (!info_ptr)
+    {
+    png_destroy_read_struct(&png_ptr,
+       (png_infopp)NULL, (png_infopp)NULL);
+    fclose (fp);
+    return eUnableToLoadImage;
+    }
+
+  // create end info structure
+  png_infop end_info = png_create_info_struct(png_ptr);
+  if (!end_info)
+    {
+    png_destroy_read_struct(&png_ptr, &info_ptr,
+      (png_infopp)NULL);
+    fclose (fp);
+    return eUnableToLoadImage;
+    }
+
+
+  // if png fails it will longjmp back to here, so we destroy the structure,
+  // close the file, and wrap up
+  if (setjmp(png_jmpbuf(png_ptr)))
+    {
+    png_destroy_read_struct(&png_ptr, &info_ptr,
+       &end_info);
+    fclose (fp);
+    return eUnableToLoadImage;
+    }
+
+
+  // initialize IO
+  png_init_io (png_ptr, fp);
+
+  // tell it we have read the sig
+  png_set_sig_bytes(png_ptr, sizeof header);
+
+  int png_transforms = PNG_TRANSFORM_STRIP_16 |    // Strip 16-bit samples to 8 bits
+                       PNG_TRANSFORM_STRIP_ALPHA | // Discard the alpha channel 
+                       PNG_TRANSFORM_PACKING |     // Expand 1, 2 and 4-bit samples to bytes
+                       PNG_TRANSFORM_BGR;          // Flip RGB to BGR, RGBA to BGRA
+
+  // read the file
+  png_read_png(png_ptr, info_ptr, png_transforms, NULL);
+
+  // note: png_read_end not needed with png_read_png (done already)
+
+  // get the row pointers
+  png_bytep * row_pointers = png_get_rows(png_ptr, info_ptr);
+
+  // make a bitmap
+  CDC B_DC;
+  B_DC.CreateCompatibleDC (NULL);
+  CBitmap B_bmp;
+
+  BITMAPINFO bmiB;
+  ZeroMemory (&bmiB, sizeof bmiB);
+
+  long bpl = BytesPerLine (info_ptr->width, 24);
+
+  bmiB.bmiHeader.biSize = sizeof bmiB;
+  bmiB.bmiHeader.biWidth =          info_ptr->width;       
+  bmiB.bmiHeader.biHeight =         info_ptr->height;
+  bmiB.bmiHeader.biPlanes =         1;
+  bmiB.bmiHeader.biBitCount =       24;
+  bmiB.bmiHeader.biCompression =    BI_RGB;
+  bmiB.bmiHeader.biSizeImage =      info_ptr->height * bpl;
+
+  unsigned char * pB = NULL;
+
+  hbmp = CreateDIBSection(NULL, &bmiB, DIB_RGB_COLORS, (void**) &pB, NULL, 0);
+
+  if (!hbmp)
+    return eUnableToLoadImage;
+
+  long row;
+  unsigned char * p = pB;
+
+  // have to reverse row order
+  for (row = 0; row < info_ptr->height; row++, p += bpl)
+     memcpy (p, row_pointers [info_ptr->height - row - 1], bpl);
+
+  // done with data
+  png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
+
+  // done with file
+  fclose(fp);
+
+  return eOK;
+  }     // end of  LoadPng
+
+
+
