@@ -46,10 +46,25 @@ int i;
 
   m_CurrentPlugin = NULL;     // no plugin active right now
 
+  m_iBackgroundMode = 0;
+  m_iForegroundMode = 0;
+  m_iBackgroundColour = NO_COLOUR;
+
+  m_TextRectangle = CRect (0, 0, 0, 0);
+  m_TextRectangleBorderOffset = 0;           
+  m_TextRectangleBorderColour = 0;           
+  m_TextRectangleBorderWidth = 0;            
+  m_TextRectangleOutsideFillColour = 0;      
+  m_TextRectangleOutsideFillStyle = 0;   
+
   m_iCurrentActionSource = eUnknownActionSource;
   m_nBytesIn = 0;
   m_nBytesOut = 0;
   m_bTabCompleteFunctions = true;
+  m_hSpecialFontHandle = 0;
+
+  m_bOutgoing_MUD_specific = false;     // server said IAC DO 102
+  m_bIncoming_MUD_specific = false;     // server said IAC WILL 102
 
   m_iTriggersEvaluatedCount = 0; 
   m_iTriggersMatchedCount = 0;   
@@ -571,6 +586,9 @@ int i;
   if (m_accelerator)
     DestroyAcceleratorTable (m_accelerator);
 
+  // if they loaded a special font, get rid of it
+  RemoveSpecialFont ();
+
 #ifdef PANE
 
   // get rid of owned panes
@@ -578,6 +596,14 @@ int i;
   safe_for_each (m_PaneMap.begin (), m_PaneMap.end (), closepane);
 #endif // PANE
 
+  // delete MiniWindow map
+
+  for (MiniWindowMapIterator mwit = m_MiniWindows.begin (); 
+       mwit != m_MiniWindows.end ();
+       mwit++)
+         delete mwit->second;
+
+
 }
 
 
