@@ -62,7 +62,6 @@ static void xmlOuputNode (lua_State *L, CXMLelement & node)
       lua_rawseti (L, -2, item);   // number each node in sequence
       } // end of checking each tag
 
-    luaL_setn (L, -1, item - 1);   // set table size now
 
     lua_rawset(L, -3);              // bind children table to "children" entry
     } // end of having children
@@ -526,7 +525,6 @@ static int functionlist (lua_State *L)
     lua_rawseti(L, -2, i + 1);  // make 1-relative
     }
 
-  luaL_setn (L, -1, i);   // set table size now
   return 1;   // 1 table
   } // end of functionlist
 
@@ -775,6 +773,53 @@ static int info (lua_State *L)
   }  // end of metaphone
 
 
+static int fontpicker  (lua_State *L) 
+  {
+  const char * fontname = luaL_optstring    (L, 1, "");     // preferred name
+  const int   fontsize  = luaL_optnumber    (L, 2, 10);     // preferred size
+  const int   fontcolour  = luaL_optnumber  (L, 3, 0);      // preferred colour
+
+
+CDC dc;
+
+  dc.CreateCompatibleDC (NULL);
+
+  LOGFONT lf;
+
+  ZeroMemory (&lf, sizeof lf);
+
+  lf.lfHeight = -MulDiv(fontsize, dc.GetDeviceCaps(LOGPIXELSY), 72);
+  strncpy (lf.lfFaceName, fontname, sizeof (lf.lfFaceName) - 1);
+  lf.lfFaceName [sizeof (lf.lfFaceName) - 1] = 0;
+
+  lf.lfWeight = FW_NORMAL;
+
+  CFontDialog dlg (&lf,
+                   CF_SCREENFONTS | CF_EFFECTS | CF_FORCEFONTEXIST,
+                   NULL,
+                   &Frame);      
+
+  if (dlg.DoModal () != IDOK)
+    {
+    lua_pushnil (L);
+    return 1;
+    }
+
+  lua_newtable(L);    // table to hold this stuff
+
+  MakeTableItem (L, "name",         dlg.GetFaceName ());
+  MakeTableItem (L, "style",        dlg.GetStyleName ());
+  MakeTableItem (L, "size",         dlg.GetSize () / 10);
+  MakeTableItem (L, "colour",       dlg.GetColor  ());
+  MakeTableItem (L, "bold",         dlg.IsBold  ());
+  MakeTableItem (L, "italic",       dlg.IsItalic  ());
+  MakeTableItem (L, "underline",    dlg.IsUnderline ());
+  MakeTableItem (L, "strikeout",    dlg.IsStrikeOut ());
+  MakeTableItem (L, "charset",      lf.lfCharSet);
+
+  return 1;    // one table
+  }  // end of fontpicker
+
 int edit_distance (lua_State *L) 
   {
   lua_pushinteger (L, EditDistance (luaL_checkstring (L, 1), luaL_checkstring (L, 2)));
@@ -1267,6 +1312,51 @@ static int showdebugstatus (lua_State *L)
   } 
 
 
+int __stdcall EnumFontFamExProc (CONST LOGFONTA * lpelfe,   // pointer to logical-font data
+                                 CONST TEXTMETRICA * lpntme,// pointer to physical-font data
+                                 DWORD FontType,            // type of font
+                                 LPARAM L_state)            // application-defined data
+                                                            
+  {
+  lua_State *L = (lua_State *) L_state;
+
+
+  lua_pushstring (L, lpelfe->lfFaceName);
+  lua_pushboolean (L, true);
+  lua_rawset(L, -3);
+
+  return 1;   // keep enumerating
+  } // end of EnumFontFamExProc
+
+
+static int getfontfamilies (lua_State *L)
+  {
+  lua_newtable(L);    // table of entries
+
+  CDC dc;
+
+  dc.CreateCompatibleDC (NULL);
+
+  LOGFONT lf;
+
+  ZeroMemory (&lf, sizeof lf);
+
+  lf.lfCharSet = DEFAULT_CHARSET;
+  lf.lfFaceName [0] = 0;
+  lf.lfPitchAndFamily = 0;
+
+  EnumFontFamiliesEx (dc.m_hDC,           // handle to device context
+                      &lf,                // pointer to logical font information
+                      EnumFontFamExProc,  // pointer to callback function
+                      (long) L,           // application-supplied data
+                      0);                 // reserved; must be zero
+
+
+  return 1;  // one table of entries
+
+  }
+
+
 // table of operations
 static const struct luaL_reg xmllib [] = 
   {
@@ -1282,6 +1372,7 @@ static const struct luaL_reg xmllib [] =
   {"functionlist",  functionlist},
   {"filepicker",    filepicker},
   {"directorypicker", directorypicker},
+  {"fontpicker",    fontpicker},
   {"metaphone",     metaphone},
   {"info",          info},
   {"spellcheckdialog", spellcheckdialog},
@@ -1293,6 +1384,7 @@ static const struct luaL_reg xmllib [] =
   {"appendtonotepad", appendtonotepad},
   {"activatenotepad", activatenotepad},
   {"showdebugstatus", showdebugstatus},
+  {"getfontfamilies", getfontfamilies},
 
   {NULL, NULL}
   };
