@@ -1381,16 +1381,6 @@ bool found = FindRoutine (pDoc,                    // passed back to callback ro
 if (found)
   {
 
-// Invalidate old selection rectangle
-
-
-  CRgn oldrgn;
-  CRgn newrgn;
-
-// Get old selection region
-
-  m_topview->get_selection (oldrgn);
-
 // because find now finds batches of lines, we must work out which line it is 
 // really on, so we highlight the correct columns
 
@@ -1454,28 +1444,14 @@ if (found)
      }
     }
 
-// Invalidate new selection rectangle
-
-// Get new selection region
-
-  m_topview->get_selection (newrgn);
-
-  // Combine previously selected with new selection, excluding union
-  oldrgn.CombineRgn (&oldrgn, &newrgn, RGN_XOR);
-
-  // Invalidate new stuff
-  m_topview->InvalidateRgn (&oldrgn);
-
-  // Finished with regions
-  newrgn.DeleteObject ();
-  oldrgn.DeleteObject ();
-
   // make sure selection visible
 
   m_topview->EnsureSelectionVisible ();
 
   }   // end of being found
 
+  // Invalidate new selection rectangle
+  m_topview->Invalidate ();
 
   } // end of CSendView::DoFind
 
@@ -2829,9 +2805,18 @@ void CSendView::AdjustCommandWindowSize (void)
   if (iLines < pDoc->m_iAutoResizeMinimumLines)
     iLines = pDoc->m_iAutoResizeMinimumLines;
 
-  // if very large, let them manage it
+  CRect rect;
+  GetClientRect (&rect);
+
   if (iLines > pDoc->m_iAutoResizeMaximumLines)
-    return;
+    {
+    // if very large, let them manage it (that is, if they have already resized it to be larger than the maximum)
+    if ((rect.bottom - rect.top) > (pDoc->m_InputFontHeight * pDoc->m_iAutoResizeMaximumLines + 4))
+      return;
+
+    // otherwise, take the maximum
+    iLines = pDoc->m_iAutoResizeMaximumLines;
+    }
 
   // resize - seem to need an extra 4 pixels or things go a bit strange
   pDoc->SetCommandWindowHeight (pDoc->m_InputFontHeight * iLines + 4);
