@@ -456,6 +456,11 @@ LONGLONG iCounterFrequency = large_int_frequency.QuadPart;
           = m_CurrentPlugin->GetPluginDispid (ON_PLUGIN_PACKET_RECEIVED);
         m_CurrentPlugin->m_dispid_plugin_partial_line 
           = m_CurrentPlugin->GetPluginDispid (ON_PLUGIN_PARTIAL_LINE);
+        m_CurrentPlugin->m_dispid_plugin_telnet_option 
+          = m_CurrentPlugin->GetPluginDispid (ON_PLUGIN_TELNET_OPTION);
+        m_CurrentPlugin->m_dispid_plugin_on_world_output_resized 
+          = m_CurrentPlugin->GetPluginDispid (ON_PLUGIN_WORLD_OUTPUT_RESIZED);
+
 
         m_CurrentPlugin->m_dispid_plugin_OnMXP_Start        
           = m_CurrentPlugin->GetPluginDispid (ON_PLUGIN_MXP_START    );
